==> freemedforms-project_0.7.1.orig.tar.gz: freemedforms-0.7.1/global_resources/translations/printerplugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>Print</name>
    <message>
        <location filename="../../plugins/printerplugin/documentprinter.cpp" line="163"/>
        <source>Made with %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrintDialog</name>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="23"/>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="106"/>
        <source>First page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="134"/>
        <source>Previous page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="156"/>
        <source># of ##</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="178"/>
        <source>Next page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="206"/>
        <source>Last page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="228"/>
        <source>Printer :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="248"/>
        <source>Presets :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="268"/>
        <source>Copies :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="284"/>
        <source>Sorted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="294"/>
        <source>Recto Verso</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="301"/>
        <source>Pages :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="311"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="320"/>
        <source>From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="340"/>
        <source>to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="356"/>
        <source>Print with duplicatas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="363"/>
        <source>Two pages per paper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="370"/>
        <source>Create a PDF copy in the cache directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.cpp" line="261"/>
        <source>Save File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.cpp" line="263"/>
        <source>PDF file (*.pdf)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrinterPreferences</name>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="14"/>
        <source>Printing preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="20"/>
        <source>Default printer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="45"/>
        <source>Default printing options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="51"/>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="59"/>
        <source>Draft</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="64"/>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="69"/>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="77"/>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="84"/>
        <source>Gray scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="91"/>
        <source>Always print two pages per paper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="104"/>
        <source>Automated copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="113"/>
        <source>Always keep a PDF copy in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="130"/>
        <source>Select a folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrinterPreferencesPage</name>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="62"/>
        <source>Printer preferences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrinterPreferencesWidget</name>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="123"/>
        <source>WARNING !
No configurated printer found on your system.
Printing and print preview should not work at all.
Please configure a printer.
Refer to your operating system documentation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="151"/>
        <source>Always use system&apos;s default printer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="155"/>
        <source>Always ask user for the printer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="226"/>
        <source>Select a directory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrinterPreviewerPrivate</name>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="44"/>
        <source>preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="62"/>
        <source>Show page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="72"/>
        <source>Show Duplicates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="79"/>
        <source>If it&apos;s checked the preview will update at each changes of text.
 This can be heavy CPU consuming.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="83"/>
        <source>Automatic update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="111"/>
        <source>Toogle preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="118"/>
        <source>Update preview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Print::Printer</name>
    <message>
        <location filename="../../plugins/printerplugin/printer.cpp" line="821"/>
        <source>Print Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="81"/>
        <source>Each Pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="82"/>
        <source>First page only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="83"/>
        <source>Second page only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="84"/>
        <source>Last page only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="85"/>
        <source>All pages but first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="86"/>
        <source>Odd pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="87"/>
        <source>Even pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="88"/>
        <source>Duplicatas only</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>tkPrinter</name>
    <message>
        <location filename="../../plugins/printerplugin/printer.cpp" line="649"/>
        <source>No content to preview (simpleDraw).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/global_resources/translations/printerplugin_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es_ES">
<context>
    <name>Print</name>
    <message>
        <location filename="../../plugins/printerplugin/documentprinter.cpp" line="163"/>
        <source>Made with %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrintDialog</name>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="23"/>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="106"/>
        <source>First page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="134"/>
        <source>Previous page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="156"/>
        <source># of ##</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="178"/>
        <source>Next page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="206"/>
        <source>Last page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="228"/>
        <source>Printer :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="248"/>
        <source>Presets :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="268"/>
        <source>Copies :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="284"/>
        <source>Sorted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="294"/>
        <source>Recto Verso</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="301"/>
        <source>Pages :</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="311"/>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="320"/>
        <source>From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="340"/>
        <source>to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="356"/>
        <source>Print with duplicates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="363"/>
        <source>Two pages per sheet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.ui" line="370"/>
        <source>Create a PDF copy in the cache directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.cpp" line="261"/>
        <source>Save File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printdialog.cpp" line="263"/>
        <source>PDF file (*.pdf)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrinterPreferences</name>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="14"/>
        <source>Printing preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="20"/>
        <source>Default printer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="45"/>
        <source>Default printing options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="51"/>
        <source>Resolution</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="59"/>
        <source>Draft</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="64"/>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="69"/>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="77"/>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="84"/>
        <source>Gray scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="91"/>
        <source>Always print two pages per paper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="104"/>
        <source>Automated copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="113"/>
        <source>Always keep a PDF copy in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.ui" line="130"/>
        <source>Select a folder</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrinterPreferencesPage</name>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="62"/>
        <source>Printer preferences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrinterPreferencesWidget</name>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="123"/>
        <source>WARNING !
No configurated printer found on your system.
Printing and print preview should not work at all.
Please configure a printer.
Refer to your operating system documentation.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="151"/>
        <source>Always use system&apos;s default printer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="155"/>
        <source>Always ask user for the printer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreferences.cpp" line="226"/>
        <source>Select a directory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Print::Internal::PrinterPreviewerPrivate</name>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="44"/>
        <source>preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="62"/>
        <source>Show page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="72"/>
        <source>Show Duplicates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="79"/>
        <source>If it&apos;s checked the preview will update at each changes of text.
 This can be heavy CPU consuming.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="83"/>
        <source>Automatic update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="111"/>
        <source>Toogle preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printerpreviewer_p.ui" line="118"/>
        <source>Update preview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Print::Printer</name>
    <message>
        <location filename="../../plugins/printerplugin/printer.cpp" line="821"/>
        <source>Print Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="81"/>
        <source>Each Pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="82"/>
        <source>First page only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="83"/>
        <source>Second page only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="84"/>
        <source>Last page only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="85"/>
        <source>All pages but first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="86"/>
        <source>Odd pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="87"/>
        <source>Even pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/printerplugin/printer.h" line="88"/>
        <source>Duplicatas only</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>tkPrinter</name>
    <message>
        <location filename="../../plugins/printerplugin/printer.cpp" line="649"/>
        <source>No content to preview (simpleDraw).</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
